package com.gic.store.web.controller;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.dto.PlatformBrandDTO;
import com.gic.enterprise.service.PlatformBrandApiService;
import com.gic.enterprise.utils.UserDetailUtils;
import com.gic.store.dto.StoreBrandDTO;
import com.gic.store.service.StoreBrandApiService;
import com.gic.store.web.qo.PageQO;
import com.gic.store.web.qo.storeBrand.StoreBrandQO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @author zhiwj
 * @date 2019/6/27
 */
@RestController
public class StoreBrandController {

    @Autowired
    private StoreBrandApiService storeBrandApiService;
    @Autowired
    private PlatformBrandApiService platformBrandApiService;

    @RequestMapping("/list-platform-brand")
    public RestResponse listPlatformBrand(String branName){
        ServiceResponse<List<PlatformBrandDTO>> serviceResponse = platformBrandApiService.listPlatformBrand(branName);
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }


    @RequestMapping("/save-store-brand")
    public RestResponse saveStoreBrand(@Validated(StoreBrandQO.SaveValidView.class) StoreBrandQO storeBrandQO) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        StoreBrandDTO storeBrandDTO = EntityUtil.changeEntity(StoreBrandDTO.class, storeBrandQO);
        storeBrandDTO.setEnterpriseId(enterpriseId);
        ServiceResponse<Integer> serviceResponse = storeBrandApiService.saveOrUpdateStoreBrand(storeBrandDTO);
        if (serviceResponse.isSuccess()) {
            return RestResponse.success();
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

    @RequestMapping("/page-store-brand")
    public RestResponse pageStoreBrand(String search, PageQO pageQO) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        ServiceResponse<Page<StoreBrandDTO>> serviceResponse = storeBrandApiService.listStoreBrand(enterpriseId, search, pageQO.getCurrentPage(), pageQO.getPageSize());
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

    @RequestMapping("/list-store-brand")
    public RestResponse listStoreBrand(String search, Integer storeSupport, Integer goodsSupport) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        ServiceResponse<List<StoreBrandDTO>> serviceResponse = storeBrandApiService.listAllStoreBrand(enterpriseId, search, storeSupport, goodsSupport);
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

    @RequestMapping("/delete-store-brand-batch")
    public RestResponse deleteByIds(String ids) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        ServiceResponse serviceResponse = storeBrandApiService.deleteByIds(enterpriseId, ids);
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage(), serviceResponse.getResult());
        }
    }
    @RequestMapping("/delete-all-store-brand-batch")
    public RestResponse delete() {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        ServiceResponse serviceResponse = storeBrandApiService.deleteAll(enterpriseId);
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage(), serviceResponse.getResult());
        }
    }


    @RequestMapping("/move-store-brand")
    public RestResponse moveStoreBrand(@Validated(StoreBrandQO.MoveValidView.class) StoreBrandQO storeBrandQO) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        ServiceResponse serviceResponse = storeBrandApiService.moveStoreBrand(enterpriseId, storeBrandQO.getStoreBrandId(), storeBrandQO.getMoveType());
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

    @RequestMapping("/set-store-brand-sort")
    public RestResponse setStoreBrandSort(@Validated({StoreBrandQO.SetSortValidView.class}) StoreBrandQO storeBrandQO) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        ServiceResponse serviceResponse = storeBrandApiService.setStoreBrandSort(enterpriseId, storeBrandQO.getStoreBrandId(), storeBrandQO.getSeq());
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

}
